<?php
if ( ! class_exists( 'IPBar_Model' )) {

    /**
     * Class for manage post setting
     */
    class IPBar_Model
    {
        
        /**
         * Save setting bar
         *
         * @param  int $barId
         * @return void
         */
        public function save_setting( $barId )
        {
            $barId   = absint( $barId );
            $data    = $this->_get_setting_data();
            $setting = new IPBar_Setting( $barId, '__ipbar-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _get_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
             
            /*
             * General
             */
            if ( ! empty( $data['layout'] )) {
                $setting['layout'] = apply_filters( 'single_post_title', $data['layout'] );
            }
            if ( isset( $data['position'] )) {
                $setting['position'] = apply_filters( 'pre_term_name', $data['position'] );
            }
            
            /*
             * Display
             */
            if ( isset( $data['default_visibility'] )) {
                $setting['default_visibility'] = apply_filters( 'pre_term_name', $data['default_visibility'] );
            }
            if ( isset( $data['close_button'] )) {
                $setting['close_button'] = apply_filters( 'pre_term_name', $data['close_button'] );
            }
            if ( isset( $data['close_button_icon'] )) {
                $setting['close_button_icon'] = apply_filters( 'pre_term_name', $data['close_button_icon'] );
            }
            if ( isset( $data['open_button_icon'] )) {
                $setting['open_button_icon'] = apply_filters( 'pre_term_name', $data['open_button_icon'] );
            }
            if ( isset( $data['open_button_color'] )) {
                $setting['open_button_color'] = apply_filters( 'pre_term_name', $data['open_button_color'] );
            }
            if ( isset( $data['open_button_bgcolor'] )) {
                $setting['open_button_bgcolor'] = apply_filters( 'pre_term_name', $data['open_button_bgcolor'] );
            }
            if ( isset( $data['open_button_position'] )) {
                $setting['open_button_position'] = apply_filters( 'pre_term_name', $data['open_button_position'] );
            }
            if ( isset( $data['delayed_time'] )) {
                $setting['delayed_time'] = absint( $data['delayed_time'] );
            }
            
            /*
             * Design
             */
            if ( isset( $data['height'] )) {
                $setting['height'] = absint( $data['height'] );
            }
            if ( isset( $data['edge_space'] )) {
                $setting['edge_space'] = absint( $data['edge_space'] );
            }
            if ( isset( $data['bg_color'] )) {
                $setting['bg_color'] = apply_filters( 'pre_term_name', $data['bg_color'] );
            }
            if ( isset( $data['gradient_color'] )) {
                $setting['gradient_color'] = apply_filters( 'pre_term_name', $data['gradient_color'] );
            }
            if ( isset( $data['text_color'] )) {
                $setting['text_color'] = apply_filters( 'pre_term_name', $data['text_color'] );
            }
            if ( isset( $data['border_color'] )) {
                $setting['border_color'] = apply_filters( 'pre_term_name', $data['border_color'] );
            }
            if ( isset( $data['border_width'] )) {
                $setting['border_width'] = absint( $data['border_width'] );
            }
            if ( isset( $data['border_radius'] )) {
                $setting['border_radius'] = apply_filters( 'pre_term_name', $data['border_radius'] );
            }
            if ( isset( $data['shadow'] )) {
                $setting['shadow'] = apply_filters( 'pre_term_name', $data['shadow'] );
            }
            
            /*
             * Effect
             */
            if ( isset( $data['animation_type'] )) {
                $setting['animation_type'] = apply_filters( 'pre_term_name', $data['animation_type'] );
            }
            if ( isset( $data['animation_speed'] )) {
                $setting['animation_speed'] = apply_filters( 'pre_term_name', $data['animation_speed'] );
            }
            if ( isset( $data['audio'] )) {
                $setting['audio'] = absint( $data['audio'] );
            }
            
            /*
             * Get setting column
             */
            $columns = array(1);
            $layout  = $setting['layout'];
            if ( strpos( $layout , 'two_column' ) !== false ) {
                $columns[] = 2;
            }
            elseif ( strpos( $layout , 'three_column' ) !== false ) {
                $columns[] = 2;
                $columns[] = 3;
            }
            foreach( $columns as $column )
            {
                $setting = $this->_get_setting_column( $column, $setting );
            }
            return $setting;
        }
        
        
        /**
         * Get setting column
         *
         * @param  array $setting
         * @param  int   $column
         * @return array
         */
        protected function _get_setting_column( $column, $setting )
        {
            $pf   = 'column_' . $column . '_';
            $data = array_merge( $_POST, $_GET );
            
            //
            //General
            //
            $_settings = array();
            
            //
            //Text
            //
            $key = $pf . 'text_content';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'text_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'text_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'text_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'text_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Image
            //
            $key = $pf . 'image_image';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'image_border_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'image_border_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'image_border_radius';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'image_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'image_height';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'image_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Logo
            //
            $key = $pf . 'logo_image';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'logo_link_active';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'logo_link_url';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_link_url', $data[$key] );
            }
            $key = $pf . 'logo_link_newwindow';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'logo_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'logo_height';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'logo_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            
            //
            //Link
            //
            $key = $pf . 'link_url';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_link_url', $data[$key] );
            }
            $key = $pf . 'link_text';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'link_newwindow';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'link_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'link_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'link_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'link_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'link_hover_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'link_hover_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Video
            //
            $key = $pf . 'video_url';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_link_url', $data[$key] );
            }
            $key = $pf . 'video_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'video_height';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'video_start';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'video_autoplay';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'video_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Countdown
            //
            $key = $pf . 'countdown_target_date';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'countdown_target_time';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'countdown_message';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'countdown_format';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_bgcolor';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_border_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_border_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'countdown_border_radius';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Custom HTML
            //
            $key = $pf . 'custom_html_code';
            if ( isset( $data[$key] )) {
                $_settings[$key] = $data[$key];
            }
            
            //
            //Facebook feeds
            //
            $key = $pf . 'facebook_feeds_pageid';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_app_id';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_app_secret';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_count';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'facebook_feeds_show_logo';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'facebook_feeds_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_link_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_link_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_link_hover_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_link_hover_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_slider_effect';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'facebook_feeds_slider_speed';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'facebook_feeds_slider_delay';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            
            //
            //Twitter feeds
            //
            $key = $pf . 'twitter_feeds_username';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_key';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_secret_key';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_token';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_token_secret';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_show_logo';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_count';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'twitter_feeds_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'twitter_feeds_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_link_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_link_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_link_hover_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_link_hover_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_slider_effect';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'twitter_feeds_slider_speed';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'twitter_feeds_slider_delay';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            
            //
            //Recent Posts
            //
            $key = $pf . 'recent_posts_count';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'recent_posts_category';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'recent_posts_title_excerpt';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_read_more';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_thumbnail';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_date_time';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_author';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'recent_posts_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_link_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_link_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_link_hover_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_link_hover_underline';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_slider_effect';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'recent_posts_slider_speed';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'recent_posts_slider_delay';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            
            //
            //Login Form
            //
            $key = $pf . 'login_form_redirect';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'login_form_placeholder_name';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'login_form_placeholder_password';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'login_form_label_name';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'login_form_label_password';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'login_form_button';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'login_form_input_bgcolor';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_input_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_input_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'login_form_input_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_input_border_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'login_form_input_border_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_input_border_radius';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_input_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'login_form_input_height';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'login_form_button_style';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_button_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'login_form_button_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Search Form
            //
            $key = $pf . 'search_form_placeholder';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'search_form_label';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'search_form_button';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'single_post_title', $data[$key] );
            }
            $key = $pf . 'search_form_input_bgcolor';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_input_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_input_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'search_form_input_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_input_border_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'search_form_input_border_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_input_border_radius';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_input_width';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'search_form_input_height';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'search_form_button_style';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_button_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'search_form_button_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Menu
            //
            $key = $pf . 'menu_select';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'menu_style';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_font_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = absint( $data[$key] );
            }
            $key = $pf . 'menu_font_family';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_bgcolor';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_hover_color';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'menu_hover_bgcolor';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            
            //
            //Social Icons
            //
            $key = $pf . 'social_icons_style';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'social_icons_size';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $key = $pf . 'social_icons_align';
            if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
            }
            $socials = array(
                'facebook'      => 'Facebook',
                'twitter'       => 'Twitter',
                'linkedin'      => 'LinkedIn',
                'google-plus'   => 'Google+',
                'stumbleupon'   => 'Stumble Upon',
                'youtube'       => 'Youtube',
                'flickr'        => 'Flickr',
                'pinterest'     => 'Pinterest',
                'delicious'     => 'Delicious',
                'rss'           => 'RSS',
                'soundcloud'    => 'Sound Cloud',
                'lastfm'        => 'Last FM',
                'digg'          => 'Digg',
                'instagram'     => 'Instagram',
                'vimeo'         => 'Vimeo',
                'tumblr'        => 'Tumblr',
                'yelp'          => 'Yelp',
                'reddit'        => 'Reddit',
                'deviantart'    => 'DeviantArt',
                'skype'         => 'Skype',
                'yahoo'         => 'Yahoo',
                'paypal'        => 'Paypal',
                'behance'       => 'Behance',
                'dribbble'      => 'Dribbble',
                'github'        => 'Gituhub',
                'vine'          => 'Vine'
            );
            foreach( $socials as $social_name => $social_title )
            {
                $key = $pf . 'social_icons_' . $social_name . '_url';
                if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_link_url', $data[$key] );
                }
                $key = $pf . 'social_icons_' . $social_name . '_on';
                if ( isset( $data[$key] )) {
                $_settings[$key] = apply_filters( 'pre_term_name', $data[$key] );
                }
            }
            
            
            //
            //Merge data setting
            //
            $type = 'text';
            $key  = $pf . 'type';
            if ( ! empty( $data[$key] )) {
            $type = apply_filters( 'pre_term_name', $data[$key] );
            }
            $kycolumn = 'column_' . $column;
            $csetting = array(
            $kycolumn => array(
                'type'      => $type,
                'settings'  => $_settings
            )
            );
            $setting  = array_merge( $setting, $csetting );
            return $setting;
        }
    }

}
?>