<?php
/*
Plugin Name: WP Notification  - Lite
Plugin URI: http://AppWholesaler.com/
Description: WP Notification Bar is a WordPress plugin that enables you to create, design and display a notification bar on your site. Unlike any ordinary notification bar, the plugin offers a wide range of contents that you can display as well as the flexibility to design the elements according to your preferences. Furthermore, the notification bar generated along with the contents are designed to be responsive so that it is readily available to all users on any device. 
Version: 1.0
Author: Stanley Jackson - App Wholesaler
Author URI: http://AppWholesaler.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPBAR_TITLE', 'WP Notification  - Lite' );
define( 'IPBAR_FILE', __FILE__ );
define( 'IPBAR_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPBAR_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPBAR_PATH . "app/setting.php" );
require_once( IPBAR_PATH . "app/setting-data.php" );
require_once( IPBAR_PATH . "app/ajax.php" );
require_once( IPBAR_PATH . "app/faicon.php" );
require_once( IPBAR_PATH . "app/font.php" );
require_once( IPBAR_PATH . "app/list.php" );
require_once( IPBAR_PATH . "app/model.php" );
require_once( IPBAR_PATH . "app/admin.php" );
require_once( IPBAR_PATH . "app/factory.php" );

/* 
require_once( IPBAR_PATH . "app/form.php" ); */

/**
 * Main class
 */
if ( ! class_exists( 'IPBar' )) {

    class IPBar
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPBAR_TITLE );
            
            add_action( 'init', array( __CLASS__, 'i18n' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ipbar', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipbar-create', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipbar-setting', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ipbar', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipbar-create', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipbar-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'global_admin_script' ), 1100 );
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( __CLASS__, 'add_meta_box' ) );
            add_action( 'save_post', array( __CLASS__, 'save_page_share' ) );
            
            //Add share object to site
            add_action( 'wp_footer', array( __CLASS__, 'factory' ) );
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            }
            
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPBAR_TITLE, 
                IPBAR_TITLE, 
                'ipbar_manage', 
                'ipbar',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipbar',
                __( 'Dashboard', 'wp_combo_bar' ), 
                __( 'Dashboard', 'wp_combo_bar' ), 
                'ipbar_manage', 
                'ipbar',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipbar',
                __( 'Create Bar', 'wp_combo_bar' ), 
                __( 'Create Bar', 'wp_combo_bar' ), 
                'ipbar_manage', 
                'ipbar-create',
                array( __CLASS__, 'admin_create' )
            );
            add_submenu_page( 
                'ipbar',
                __( 'Settings', 'wp_combo_bar' ), 
                __( 'Settings', 'wp_combo_bar' ), 
                'ipbar_manage', 
                'ipbar-setting',
                array( __CLASS__, 'setting' )
            );
        }
        
        /**
         * Handle internationalization
         *
         * @return void
         */
        public static function i18n()
        {
            load_plugin_textdomain( 'wp_combo_bar', false, basename( IPBAR_PATH ) . '/languages/' );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipbar_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPBar_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPBar_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator create notification
         *
         * @return void
         */
        public static function admin_create()
        {
            $display = new IPBar_Admin();
            $display->create();
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function setting()
        {
            $display = new IPBar_Admin();
            $display->setting();
        }
        
        /**
         * Share factory
         *
         * @return void
         */
        public static function factory()
        {
            global $ipbar;
            
            if ( ! $ipbar ) {
                $ipbar = new IPBar_Factory();
            }
            $ipbar->render();
        }
        
        /**
         * Add administrator meta box
         *
         * @return void
         */
        public static function add_meta_box()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ipbar_metabox',
                    __( 'Combo Bar Settings', 'wp_combo_bar' ),
                    array( __CLASS__, 'meta_box_content' ),
                    $screen,
                    'side'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public static function meta_box_content( $post )
        {
            $display = new IPBar_Admin();
            $display->meta_box( $post );
        }
        
        /**
         * Save page/post meta box setting
         *
         * @return void
         */
        public static function save_page_share( $post_id )
        {
            if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
                if ( ! current_user_can( 'edit_page', $post_id ) ) {
                    return;
                }
            } else {
                if ( ! current_user_can( 'edit_post', $post_id ) ) {
                    return;
                }
            }
            // Check if the user intended to change this value.
            if ( ! isset( $_POST['ipbar_mbox_nonce'] ) ) {
                return;
            }
            $post_ID = $_POST['post_ID'];
            $barId   = sanitize_text_field( $_POST['ipbar_id'] );
            update_post_meta( $post_ID, '__ipbar_page_bar', $barId );
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ipbar-admin-style');
            wp_register_style('ipbar-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipbar-admin-style');
            
            wp_deregister_style('ipbar-public-style');
            wp_register_style('ipbar-public-style', plugin_dir_url( __FILE__ ) . 'css/public.css', false, null);
            wp_enqueue_style('ipbar-public-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('ipbar-admin-style-global');
            wp_register_style('ipbar-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ipbar-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var ipbar_img_url  = '<?php echo IPBAR_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPBAR_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_combo_bar' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_combo_bar' ); ?>'
                },
                ipbar_favicon_base = '<?php echo IPBAR_BASE_URL . 'img/favicon/'; ?>';
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipbar-admin-script');
            wp_enqueue_script(
                'ipbar-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function global_admin_script($hook)
        {
            wp_deregister_script('ipbar-admin-global-script');
            wp_enqueue_script(
                'ipbar-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $ipbar;
            if ( ! $ipbar ) {
                $ipbar = new IPBar_Factory();
            }
            $setting = $ipbar->setting();
        ?>
            <script type="text/javascript">
                var ipbar_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ipbar-public-script');
            wp_enqueue_script(
                'ipbar-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPBar::setup();
?>