<?php
if ( ! class_exists( 'IPBar_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPBar_Admin
    {
        /**
         * Show content admin home
         *
         * @return void
         */
        public function index()
        {
            $this->view( 'dashboard' );
        }
        
        /**
         * Show content for create bar
         *
         * @return void
         */
        public function create()
        {   
            $this->view( 'create' );
        }
        
        /**
         * Show content for edit bar
         *
         * @return void
         */
        public function edit()
        {
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
            
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_combo_bar') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $bar = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp_combo_bar') );
            }
            //Set variable
            $this->bar          = $bar;
            $this->setting      = new IPBar_Setting( $id, '__ipbar-setting' );
            
            $this->view( 'edit' );
        }
        
        /**
         * Show content for setting administrator
         *
         * @return void
         */
        public function setting()
        {
            $this->view( 'setting' );
        }
        
        /**
         * Show content for meta box
         *
         * @return void
         */
        public function meta_box( $post )
        {
        ?>
            <div id="ipbar_metaBox">
                <p><strong><?php _e( 'Select Bar', 'wp_combo_bar' ); ?></strong></p>
                <label for="ipbar-bar" class="screen-reader-text"><?php _e( 'Select Bar', 'wp_combo_bar' ); ?></label>
                <select name="ipbar_id" id="ipbar-bar">
                    <option value="0"><?php _e( 'None', 'wp_combo_bar' ); ?></option>
                    <?php
                    $current = get_post_meta( $post->ID, '__ipbar_page_bar', true );
                    $bars    = $this->_get_bar_objects();
                    if ( ! empty( $bars )) 
                    {
                        foreach( $bars as $bar ) 
                        {
                            $sltd = '';
                            if ( $bar->ID == $current ) {
                                $sltd = ' selected="selected"';
                            }
                            echo '<option value="' . $bar->ID . '"' . $sltd . '>' . $bar->post_title . '</option>';
                        }
                    }
                    ?>
                </select>
                <?php wp_nonce_field( plugin_basename( __FILE__ ), 'ipbar_mbox_nonce' ); ?>
            </div>
        <?php
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPBAR_PATH . 'app/views/admin/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get content types
         *
         * @return array
         */
        public function getContentTypes()
        {
            $contentTypes = array(
                'text'              => __( 'Text', 'wp_combo_bar' ),
                'link'              => __( 'Link', 'wp_combo_bar' ),
                'image'             => __( 'Image', 'wp_combo_bar' ),
                'logo'              => __( 'Logo', 'wp_combo_bar' ),
                'video'             => __( 'Video', 'wp_combo_bar' ),
                'social_icons'      => __( 'Social Icons', 'wp_combo_bar' ),
                'facebook_feeds'    => __( 'Facebook Feeds', 'wp_combo_bar' ),
                'twitter_feeds'     => __( 'Twitter Feeds', 'wp_combo_bar' ),
                'countdown'         => __( 'Countdown', 'wp_combo_bar' ),
                'recent_posts'      => __( 'Recent Posts', 'wp_combo_bar' ),
                'menu'              => __( 'Menu', 'wp_combo_bar' ),
                'custom_html'       => __( 'Custom HTML', 'wp_combo_bar' ),
                'login_form'        => __( 'Login Form', 'wp_combo_bar' ),
                'search_form'       => __( 'Search Form', 'wp_combo_bar' )
            );
            return $contentTypes;
        }
        
        /**
         * Get type label
         *
         * @param string $type
         * @return void
         */
        public function getTypeLabel( $type )
        {
            $contentTypes = $this->getContentTypes();
            $label = $type;
            if ( array_key_exists( $type, $contentTypes )) {
                $label = $contentTypes[$type];
            }
            return $label;
        }
        
        /**
         * Admin header template
         *
         * @param string $page
         * @return void
         */
        public function header( $page, $title = '', $info = '', $icon = '' )
        {
            $struct = array(
                'ipbar' => array(
                    'title'     => __( 'Dashboard', 'wp_combo_bar' ),
                    'info'      => __( 'See all barication bar and manage it', 'wp_combo_bar' ),
                    'icon'      => 'dashboard'
                ),
                'ipbar-create' => array(
                    'title'     => __( 'Create Bar', 'wp_combo_bar' ),
                    'info'      => __( 'Create new barication bar for your website', 'wp_combo_bar' ),
                    'icon'      => 'plus-circle'
                ),
                'ipbar-setting' => array(
                    'title'     => __( 'Settings', 'wp_combo_bar' ),
                    'info'      => __( 'Set the bar settings', 'wp_combo_bar' ),
                    'icon'      => 'cog'
                )
            );
        ?>
            <div class="ipbe-top">
                <div class="ipbe-header">
                    <div class="ipbe-page-title">
                        <h1>
                            <i class="ibe ibe-bell"></i>
                            <span>
                                <strong><span>WP</span> Combo Bar</strong>
                                <em><?php _e( 'WordPress plugin to create special barication bar in your website','wp_combo_bar' ); ?></em>
                            </span>
                        </h1>
                    </div>
                </div>
                <div class="ipbe-nav">
                    <ul>
                    <?php
                    if ( array_key_exists( $page, $struct ))
                    {
                        if ( empty( $title )) {
                            $title = $struct[$page]['title'];
                        }
                        if ( empty( $info )) {
                            $info  = $struct[$page]['info'];
                        }
                        if ( empty( $icon )) {
                            $icon  = $struct[$page]['icon'];
                        }
                    }
                    foreach( $struct as $name => $data ) 
                    {
                        $active = '';
                        if ( $page == $name ) {
                            $active = ' class="active"';
                        }
                        echo '<li' . $active . '>' .
                                '<a href="admin.php?page=' . $name . '">' .
                                    '<i class="ibe ibe-' . $data['icon'] . '"></i>' .
                                    $data['title'] .
                                '</a>' .
                            '</li>';
                    }
                    ?>
                    </ul>
                </div>
                <div class="ipbe-page-info">
                    <i class="ibe ibe-<?php echo $icon; ?>"></i>
                    <div class="ipbe-info">
                        <h2><?php echo $title; ?></h2>
                        <h3><?php echo $info; ?></h3>
                    </div>
                </div>
            </div>
        <?php
        }
        
        /**
         * Get bar objects
         *
         * @return array
         */
        protected function _get_bar_objects()
        {
            $args = array(
                'orderby'        => 'post_title',
                'order'          => 'DESC', 
                'post_type'      => 'ipbar-item',
                'post_status'    => array('publish'),
                'posts_per_page' => -1,
                'paged'          => 1
            );
            $query = new WP_Query;
            $bars  = $query->query( $args );
            return $bars;
        }
    }
}