<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPBar_Ajax' )) {

    class IPBar_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipbar_create'            => 'create',
            'ipbar_edit'              => 'edit',
            'ipbar_delete'            => 'delete',
            'ipbar_change_type'       => 'change_type',
            'ipbar_setting'           => 'setting',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipbar'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Create new bar
         *
         * @return void
         */
        public function create()
        {
            $error  = true;
            $bar_id = $this->_add_bar();
            if ( $bar_id )
            {
                $layout = 'one_column';
                if ( ! empty( $_POST['layout'] )) {
                    $layout = apply_filters( 'single_post_title', $_POST['layout'] );
                }
                $data = array(
                    'layout' => $layout
                );
                $setting = new IPBar_Setting( $bar_id, '__ipbar-setting' );
                $result  = $setting->setSettings( $data );
                $error   = false;
            }
            
            if ( $error ) {
                $status  = 0;
                $bar_id  = 0;
                $message = __( 'Failed to create a notification bar.', 'wp_combo_bar' );
            } else {
                $status = 1;
                $message  = __( 'Successfully create a notification bar.', 'wp_combo_bar' );
                $redirect = admin_url() . 'admin.php?page=ipbar&action=edit&id=' . $bar_id;
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'barid'    => $bar_id
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Edit bar
         *
         * @return void
         */
        public function edit()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['bar_id'] )) {
                $barId = absint( $_POST['bar_id'] );
                if ( $bar = get_post( $barId ) ) {
                    $this->_update_bar( $bar );
                    $error = false;
                }
            }
            if ( $error ) {
                $status  = 0;
                $message = __( 'Failed to change bar settings.', 'wp_combo_bar' );
            } else {
                $status  = 1;
                $message = __( 'Successfully to change bar settings.', 'wp_combo_bar' );
            }
            $result = array(
                'status'   => $status,
                'message'  => $message
            );
            echo json_encode( $result );
            die();
        }
        
        /**
         * Update bar
         *
         * @param  object $bar
         * @return boolean
         */
        protected function _update_bar( $bar )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $bar->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            /* 
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $bar->post_status ) {
                $dataPost['post_status'] = $status;
            } 
            */
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $bar->ID;
                $result = wp_update_post( $dataPost );
            }
            //
            //Update setting
            $model = new IPBar_Model();
            $model->save_setting( $bar->ID );
                
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_combo_bar' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the barication bar.', 'wp_combo_bar' ),
                    'redirect' => admin_url() . 'admin.php?page=ipbar&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the barication bar.', 'wp_combo_bar' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for change column type
         *
         * @return void
         */
        public function change_type()
        {
            if ( empty( $_POST['type'] ) || empty( $_POST['column'] ) || empty( $_POST['bar'] ))
            {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to change column type.', 'wp_combo_bar' )
                ) );
            }
            $barId  = absint( $_POST['bar'] );
            $column = absint( $_POST['column'] );
            $type   = apply_filters( 'pre_term_name', $_POST['type'] );
            //
            //Check bar
            if ( ! $bar = get_post( $barId ))
            {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to change column type.', 'wp_combo_bar' )
                ) );
            }
            
            $setting  = new IPBar_Setting( $barId, '__ipbar-setting' );
            $tsetting = $setting->getSetting( 'column_' . $column );

            $settings = array();
            if ( is_array( $setting )) {
                if ( ! empty( $setting['settings'] )) {
                    $settings = (array)$setting['settings'];
                }
            }
            
            $this->bar          = $bar;
            $this->setting      = $setting;
            $this->type_setting = new IPBar_Setting_Data( $settings );
            $this->column       = $column;
            
            //
            //Include view
            $view = 'edit/content/' . $type;
            ob_start();
            $this->view( $view );
            $form = ob_get_clean();
            
            if ( ! empty( $form )) 
            {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully change column type.', 'wp_combo_bar' ),
                    'type'    => $type,
                    'title'   => $this->getTypeLabel( $type ),
                    'form'    => $form
                ) );
            }
            else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to change column type.', 'wp_combo_bar' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( isset( $_POST['home_bar'] )) {
                $this->_save_setting( 'home_bar' );
            }
            if ( isset( $_POST['general_bar'] )) {
                $this->_save_setting( 'general_bar' );
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update bar settings.', 'wp_combo_bar' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to update bar settings.', 'wp_combo_bar' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Save setting
         *
         * @param  string $name
         * @return boolean
         */
        protected function _save_setting( $name )
        {
            if ( ! empty( $_POST[$name] ))
            {
                $barId = absint( $_POST[$name] );
                if ( $bar = get_post( $barId ))
                {
                    update_option( '__ipbar_' . $name, $barId );
                }
            } else {
                update_option( '__ipbar_' . $name, 0 );
            }
            return true;
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPBAR_PATH . 'app/views/admin/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get content types
         *
         * @return array
         */
        public function getContentTypes()
        {
            $contentTypes = array(
                'text'              => __( 'Text', 'wp_combo_bar' ),
                'link'              => __( 'Link', 'wp_combo_bar' ),
                'image'             => __( 'Image', 'wp_combo_bar' ),
                'logo'              => __( 'Logo', 'wp_combo_bar' ),
                'video'             => __( 'Video', 'wp_combo_bar' ),
                'social_icons'      => __( 'Social Icons', 'wp_combo_bar' ),
                'facebook_feeds'    => __( 'Facebook Feeds', 'wp_combo_bar' ),
                'twitter_feeds'     => __( 'Twitter Feeds', 'wp_combo_bar' ),
                'countdown'         => __( 'Countdown', 'wp_combo_bar' ),
                'recent_posts'      => __( 'Recent Posts', 'wp_combo_bar' ),
                'menu'              => __( 'Menu', 'wp_combo_bar' ),
                'custom_html'       => __( 'Custom HTML', 'wp_combo_bar' ),
                'login_form'        => __( 'Login Form', 'wp_combo_bar' ),
                'search_form'       => __( 'Search Form', 'wp_combo_bar' )
            );
            return $contentTypes;
        }
        
        /**
         * Get type label
         *
         * @param string $type
         * @return void
         */
        public function getTypeLabel( $type )
        {
            $contentTypes = $this->getContentTypes();
            $label = $type;
            if ( array_key_exists( $type, $contentTypes )) {
                $label = $contentTypes[$type];
            }
            return $label;
        }
        
        /**
         * Add new barication bar
         *
         * @return int
         */
        protected function _add_bar()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $dataPost = array(
                'post_status'  => 'publish', 
                'post_type'    => 'ipbar-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
    }
}